-- Mod: Animal Status
-- Author: Oectacan
-- email: vyeryomin@gmail.com

local modDesc = loadXMLFile("modDesc", g_currentModDirectory .. "modDesc.xml");

animalStatus = {};
animalStatus.version = getXMLString(modDesc, "modDesc.version");
animalStatus.modDirectory = g_currentModDirectory;
hudActive = false;

addModEventListener(animalStatus);

function animalStatus:loadMap()

	print("--- Animal Info v.:" .. self.version .. ", by Oectacan loaded");

end;

function animalStatus:keyEvent(unicode, sym, modifier, isDown)
end;

function animalStatus:mouseEvent(posX, posY, isDown, isUp, button)
end;

function animalStatus:deleteMap()
end;

function animalStatus:update(dt)

	if InputBinding.hasEvent(InputBinding.SHOW_INFO) then
		hudActive =not hudActive;
	end;	

end;

function animalStatus:draw()

	if hudActive == true then

		local posX = 0.89; -- Data X position
		local posX2 = posX + 0.1; -- Data offset X position
		local posY = 0.8; -- Data Y position
		local blockPadding = 0.005; -- Padding between blocks
		local fontSize = 0.010; -- Font size
		local lineDist = fontSize + 0.002;  -- Distance between lines
		setTextColor(1,1,1,1);

		--Render content
		function fShowResource(resourceTitle, resourceValue, resourceUnit, isBold)
				setTextAlignment(RenderText.ALIGN_LEFT);
				if isBold == "bold" then setTextBold(true) end;
				renderText(posX, posY, fontSize, resourceTitle .. ": ");
				setTextAlignment(RenderText.ALIGN_RIGHT);
				renderText(posX2, posY, fontSize, resourceValue .. " " .. resourceUnit);
				setTextBold(false);
				posY = posY - lineDist;
				setTextColor(1,1,1,1);
		end;

		--Warning end alert text color change
		function fCheckWarning(resourceValue, warningLevel, alertLevel, direction)
			if direction == "asc" then
				if resourceValue >= alertLevel then
					setTextColor(1,0,0,1);
				elseif alertLevel > resourceValue and resourceValue >= warningLevel then
					setTextColor(1,1,0,1);
				end;
			elseif direction == "desc" then
				if resourceValue <= alertLevel then
					setTextColor(1,0,0,1);
				elseif alertLevel < resourceValue and resourceValue <= warningLevel then
					setTextColor(1,1,0,1);
				end;
			end;
		end;

		--Add padding between blocks
		function fEndOfBlock()
			posY = posY - blockPadding;
		end

		--Chickens info
		if g_currentMission.husbandries.chicken.totalNumAnimals > 1 then
			--Num anumals
			fShowResource("Chickens", g_currentMission.husbandries.chicken.totalNumAnimals, "pcs", "bold");
			--Eggs
			fCheckWarning(g_currentMission.husbandries.chicken.numActivePickupObjects, 20, 22, "asc");
			fShowResource("eggs", g_currentMission.husbandries.chicken.numActivePickupObjects, "pcs");
			fEndOfBlock();
		end;

		--Sheeps info
		if g_currentMission.husbandries.sheep.totalNumAnimals > 0 then
			--Num animals
			fShowResource("Sheeps", g_currentMission.husbandries.sheep.totalNumAnimals, "pcs", "bold");
			--Productivity
			fCheckWarning(g_currentMission.husbandries.sheep.productivity, 0.90, 0, "desc");
			fShowResource("productivity", math.ceil(g_currentMission.husbandries.sheep.productivity * 100), "%");
			--Cleanliness
			fCheckWarning(g_currentMission.husbandries.sheep.cleanlinessFactor, 0.50, 0, "desc");
			fShowResource("cleanliness", math.ceil(g_currentMission.husbandries.sheep.cleanlinessFactor * 100), "%");
			--Water
			fCheckWarning(g_currentMission.husbandries.sheep:getFillLevel(FillUtil.FILLTYPE_WATER), 1000, 0, "desc");			
			fShowResource("water", math.ceil(g_currentMission.husbandries.sheep:getFillLevel(FillUtil.FILLTYPE_WATER)), "l");
			--Grass + DryGrass
			fCheckWarning(g_currentMission.husbandries.sheep:getFillLevel(FillUtil.FILLTYPE_GRASS_WINDROW) + g_currentMission.husbandries.sheep:getFillLevel(FillUtil.FILLTYPE_DRYGRASS_WINDROW), 1000, 0, "desc");			
			fShowResource("grass", math.ceil(g_currentMission.husbandries.sheep:getFillLevel(FillUtil.FILLTYPE_GRASS_WINDROW) + g_currentMission.husbandries.sheep:getFillLevel(FillUtil.FILLTYPE_DRYGRASS_WINDROW)), "l");
			--Wool
			if g_currentMission.husbandries.sheep.currentPallet == nil then
				fShowResource("wool", "n/a", "");
			else
				fCheckWarning(g_currentMission.husbandries.sheep.currentPallet.fillLevel, 1900, 2000, "asc");
				fShowResource("wool", math.ceil(g_currentMission.husbandries.sheep.currentPallet.fillLevel), "l");
			end;
			fEndOfBlock();
		end;

		--Pigs info
		if g_currentMission.husbandries.pig.totalNumAnimals > 0 then
			--Num animals
			fShowResource("Pigs", g_currentMission.husbandries.pig.totalNumAnimals, "pcs", "bold");
			--Productivity
			fCheckWarning(g_currentMission.husbandries.pig.productivity, 0.90, 0, "desc");
			fShowResource("productivity", math.ceil(g_currentMission.husbandries.pig.productivity * 100), "%");
			--Cleanliness
			fCheckWarning(g_currentMission.husbandries.pig.cleanlinessFactor, 0.50, 0, "desc");
			fShowResource("cleanliness", math.ceil(g_currentMission.husbandries.pig.cleanlinessFactor * 100), "%");
			--Water
			fCheckWarning(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_WATER), 1000, 0, "desc");
			fShowResource("water", math.ceil(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_WATER)), "l");
			--Straw
			fCheckWarning(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_STRAW), 1000, 0, "desc");			
			fShowResource("straw", math.ceil(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_STRAW)), "l");
			--Maize
			fCheckWarning(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_MAIZE), 1000, 0, "desc");			
			fShowResource("maize", math.ceil(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_MAIZE)), "l");
			--Wheat, Barley
			fCheckWarning(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_WHEAT) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_BARLEY), 1000, 0, "desc");			
			fShowResource("grain", math.ceil(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_WHEAT) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_BARLEY)), "l");
			--Rape, Sunflower, Soybean
			fCheckWarning(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_RAPE) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_SUNFLOWER) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_SOYBEAN), 1000, 0, "desc");
			fShowResource("bean", math.ceil(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_RAPE) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_SUNFLOWER) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_SOYBEAN)), "l");
			--Potato, Sugarbeets
			fCheckWarning(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_POTATO) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_SUGARBEET), 1000, 0, "desc");			
			fShowResource("earth fruits", math.ceil(g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_POTATO) + g_currentMission.husbandries.pig:getFillLevel(FillUtil.FILLTYPE_SUGARBEET)), "l");
			--Liquid manure
			fCheckWarning(g_currentMission.husbandries.pig.liquidManureTrigger.fillLevel, 750000, 800000, "asc");			
			fShowResource("liquid manure", math.ceil(g_currentMission.husbandries.pig.liquidManureTrigger.fillLevel), "l");
			--Solid manure
			fCheckWarning(g_currentMission.husbandries.pig.manureFillLevel, 350000, 400000, "asc");			
			fShowResource("manure heap", math.ceil(g_currentMission.husbandries.pig.manureFillLevel), "l");
			fEndOfBlock();
		end;

		--Cows info
		if g_currentMission.husbandries.cow.totalNumAnimals > 0 then
			--Num animals
			fShowResource("Cows", g_currentMission.husbandries.cow.totalNumAnimals, "pcs", "bold");
			--Productivity
			fCheckWarning(g_currentMission.husbandries.cow.productivity, 0.90, 0, "desc");
			fShowResource("productivity", math.ceil(g_currentMission.husbandries.cow.productivity * 100), "%");
			--Cleanliness
			fCheckWarning(g_currentMission.husbandries.cow.cleanlinessFactor, 0.50, 0, "desc");
			fShowResource("cleanliness", math.ceil(g_currentMission.husbandries.cow.cleanlinessFactor * 100), "%");
			--Water
			fCheckWarning(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_WATER), 1000, 0, "desc");
			fShowResource("water", math.ceil(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_WATER)), "l");
			--Straw
			fCheckWarning(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_STRAW), 1000, 0, "desc");
			fShowResource("straw", math.ceil(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_STRAW)), "l");
			--Grass
			fCheckWarning(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_GRASS_WINDROW), 1000, 0, "desc");
			fShowResource("grass", math.ceil(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_GRASS_WINDROW)), "l");
			--Silage
			fCheckWarning(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_DRYGRASS_WINDROW) + g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_SILAGE), 1000, 0, "desc");
			fShowResource("silage", math.ceil(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_DRYGRASS_WINDROW) + g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_SILAGE)), "l");
			--Powerfood
			fCheckWarning(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_POWERFOOD), 1000, 0, "desc");
			fShowResource("TMR", math.ceil(g_currentMission.husbandries.cow:getFillLevel(FillUtil.FILLTYPE_POWERFOOD)), "l");
			--Liquid manure
			fCheckWarning(g_currentMission.husbandries.cow.liquidManureTrigger.fillLevel, 750000, 800000, "asc");			
			fShowResource("liquid manure", math.ceil(g_currentMission.husbandries.cow.liquidManureTrigger.fillLevel), "l");
			--Solid manure
			fCheckWarning(g_currentMission.husbandries.cow.manureFillLevel, 350000, 400000, "asc");			
			fShowResource("manure heap", math.ceil(g_currentMission.husbandries.cow.manureFillLevel), "l");
			--Milk
			fShowResource("milk", math.ceil(g_currentMission.husbandries.cow.fillLevelMilk), "l");
			fEndOfBlock();
		end;

			setTextAlignment(RenderText.ALIGN_RIGHT);
			renderText(posX2, posY, 0.008, "Animal Status v.:" .. self.version);

		setTextAlignment(RenderText.ALIGN_LEFT); -- other mods compability

	end;

end;